Optimization
============


.. toctree::
   :caption: Modules:
   :maxdepth: 1
   :glob:

   Modules/*

.. toctree::
   :caption: Least Squares:
   :maxdepth: 1
   :glob:

   Least_Squares/*

.. autoclass:: gmmvi.optimization.sample_db.SampleDB
   :members:

.. autoclass:: gmmvi.optimization.gmmvi.GMMVI
   :members: